AudioResolverResult class
Result of resolving an audio stream for a YouTube video.
Constructors
- AudioResolverResult({required String videoId, required String url, required int itag, required String mimeType, required String codec, required int bitrate, required int? contentLength, required double? loudnessDb, required String clientUsed, required String userAgent, required DateTime expiresAt})
-
const
-
AudioResolverResult.fromMap(Map<
String, dynamic> map) -
Create from a Map (from platform channel)
factory
Properties
- bitrate → int
-
final
- clientUsed → String
-
final
- codec → String
-
final
- contentLength → int?
-
final
- expiresAt → DateTime
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isExpired → bool
-
no setter
- itag → int
-
final
- loudnessDb → double?
-
final
- mimeType → String
-
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - url → String
-
final
- userAgent → String
-
final
- videoId → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> - Convert to Map (for platform channel)
-
toString(
) → String - A string representation of this object.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited