MethodChannelAudiosResolver class

The method channel implementation of AudiosResolverPlatform.

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
The method channel used to interact with the native platform.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearCache() Future<void>
Clear the cache.
override
fetchBatch({required List<String> videoIds, bool forceRefresh = false, int concurrency = 5}) Future<Map<String, AudioResolverResult?>>
Resolve multiple video IDs to audio URLs.
override
fetchSingle({required String videoId, bool forceRefresh = false}) Future<AudioResolverResult?>
Resolve a single video ID to an audio URL.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited