AudiosResolverPlatform class abstract
The interface that platform implementations must implement.
- Inheritance
-
- Object
- PlatformInterface
- AudiosResolverPlatform
- Implementers
Constructors
- AudiosResolverPlatform()
- Constructs a AudiosResolverPlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clearCache(
) → Future< void> - Clear the cache.
-
fetchBatch(
{required List< String> videoIds, bool forceRefresh = false, int concurrency = 5}) → Future<Map< String, AudioResolverResult?> > - Resolve multiple video IDs to audio URLs.
-
fetchSingle(
{required String videoId, bool forceRefresh = false}) → Future< AudioResolverResult?> - Resolve a single video ID to an audio URL.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ AudiosResolverPlatform
-
The default instance of AudiosResolverPlatform to use.
getter/setter pair